@@ -4,12 +4,14 @@
 
     Lexers for non-source code file types.
 
-    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2024 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
+# ruff: noqa: F401
 from pygments.lexers.configs import ApacheConfLexer, NginxConfLexer, \
-    SquidConfLexer, LighttpdConfLexer, IniLexer, RegeditLexer, PropertiesLexer
+    SquidConfLexer, LighttpdConfLexer, IniLexer, RegeditLexer, PropertiesLexer, \
+    UnixConfigLexer
 from pygments.lexers.console import PyPyLogLexer
 from pygments.lexers.textedit import VimLexer
 from pygments.lexers.markup import BBCodeLexer, MoinWikiLexer, RstLexer, \
